@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2022, by Samuel Williams.
+# Copyright, 2021-2023, by Samuel Williams.
 
 require_relative 'assertions'
 require_relative 'identity'
@@ -16,15 +16,21 @@ module Sus
 			base.children = Hash.new
 		end
 		
-		def to_s
-			self.description || self.name
-		end
-		
-		def inspect
-			if description = self.description
-				"\#<#{self.name || "Context"} #{self.description}>"
-			else
-				self.name
+		unless respond_to?(:set_temporary_name)
+			def set_temporary_name(name)
+				# No-op.
+			end
+			
+			def to_s
+				(self.description || self.name).to_s
+			end
+			
+			def inspect
+				if description = self.description
+					"\#<#{self.name || "Context"} #{self.description}>"
+				else
+					self.name
+				end
 			end
 		end
 		
