@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2022, by Samuel Williams.
+# Copyright, 2021-2023, by Samuel Williams.
 
 require_relative 'context'
 
@@ -12,6 +12,7 @@ module Sus
 			base.extend(It)
 			base.description = description
 			base.identity = Identity.nested(parent.identity, base.description, unique: unique)
+			base.set_temporary_name("#{self}[#{description}]")
 			
 			if block_given?
 				base.define_method(:call, &block)
@@ -64,5 +65,17 @@ module Sus
 			@__assertions__.skip(reason)
 			throw :skip, reason
 		end
+		
+		def skip_unless_method_defined(method, target)
+			unless target.method_defined?(method)
+				skip "Method #{method} is not defined in #{target}!"
+			end
+		end
+		
+		def skip_unless_constant_defined(constant, target = Object)
+			unless target.const_defined?(constant)
+				skip "Constant #{constant} is not defined in #{target}!"
+			end
+		end
 	end
 end
