@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2022, by Samuel Williams.
+# Copyright, 2021-2023, by Samuel Williams.
 # Copyright, 2022, by Brad Schrag.
 
 require_relative 'base'
@@ -35,7 +35,7 @@ module Sus
 		end
 		
 		def to_s
-			@base.identity.to_s
+			@base&.identity&.to_s || self.class.name
 		end
 		
 		def load(path)
